.. _`examples-label`:

Examples
========

Some examples of b2luigi in Belle II
------------------------------------

These are some examples of how to use b2luigi in Belle II.
Please keep in mind, that some of these examples are based on older versions of b2luigi.
Some functionalities did not yet exist or were created in these projects and later adapted to b2luigi.
If you know a project that should be listed here, please feel free to open a merge request.

*   `PERC by Alexander Heidelbach <https://gitlab.desy.de/alexander.heidelbach/photonenergyresolutioncalibration>`_
*   `VIBE <https://gitlab.desy.de/belle2/data-production/validation/vibe>`_
*   `B to X l nu analysis by Moritz Bauer <https://gitlab.desy.de/belle2/analyses/mbauer_btoxulnu_analysis>`_
*   `Inelastic Dark Matter with a Dark Higgs Search by Patrick Ecker <https://gitlab.desy.de/belle2/publications/70/idmdarkhiggs>`_

.. toctree::
    :maxdepth: 2

    examples/basf2-examples
